@@ -1,14 +1,10 @@
 // RUN: %libomptarget-compilexx-generic -O3 && %libomptarget-run-generic
-
-// Hangs
-// UNSUPPORTED: amdgcn-amd-amdhsa
-// UNSUPPORTED: amdgcn-amd-amdhsa-newRTL
-// UNSUPPORTED: amdgcn-amd-amdhsa-newDriver
+// RUN: %libomptarget-compilexx-generic -O3 -ffast-math && %libomptarget-run-generic
 
 #include <iostream>
 
 template <typename T> int test_map() {
-  std::cout << "map(complex<>)" << std::endl;
+  std::cout << "map(T)" << std::endl;
   T a(0.2), a_check;
 #pragma omp target map(from : a_check)
   { a_check = a; }
@@ -31,8 +27,8 @@ template <typename T> int test_reduction() {
     sum_host += array[i];
   }
 
-#pragma omp target teams distribute parallel for map(to: array[:size])         \
-                                                 reduction(+ : sum)
+#pragma omp target teams distribute parallel for map(to : array[ : size])      \
+    reduction(+ : sum)
   for (int i = 0; i < size; i++)
     sum += array[i];
 
@@ -42,10 +38,8 @@ template <typename T> int test_reduction() {
   std::cout << "hierarchical parallelism" << std::endl;
   const int nblock(10), block_size(10);
   T block_sum[nblock];
-#pragma omp target teams distribute map(to                                     \
-                                        : array[:size])                        \
-    map(from                                                                   \
-        : block_sum[:nblock])
+#pragma omp target teams distribute map(to : array[ : size])                   \
+    map(from : block_sum[ : nblock])
   for (int ib = 0; ib < nblock; ib++) {
     T partial_sum = 0;
     const int istart = ib * block_size;
@@ -69,7 +63,7 @@ template <typename T> int test_reduction() {
   return 0;
 }
 
-template <typename T> int test_complex() {
+template <typename T> int test_POD() {
   int ret = 0;
   ret |= test_map<T>();
   ret |= test_reduction<T>();
@@ -79,8 +73,8 @@ template <typename T> int test_complex() {
 int main() {
   int ret = 0;
   std::cout << "Testing float" << std::endl;
-  ret |= test_complex<float>();
+  ret |= test_POD<float>();
   std::cout << "Testing double" << std::endl;
-  ret |= test_complex<double>();
+  ret |= test_POD<double>();
   return ret;
 }
